package de.intevation.flys.artifacts.model;

import org.apache.log4j.Logger;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.states.DefaultState.ComputeType;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class HistoricalDischargeFacet extends DataFacet {

    private static final Logger logger =
        Logger.getLogger(HistoricalDischargeFacet.class);


    public HistoricalDischargeFacet() {
    }


    public HistoricalDischargeFacet(int index, String name, String desc) {
        super(index, name, desc, ComputeType.ADVANCE, null, null);
    }


    public HistoricalDischargeFacet(
        int         index,
        String      name,
        String      description,
        ComputeType type,
        String      stateID,
        String      hash

    ) {
        super(index, name, description, type, hash, stateID);
    }


    @Override
    public Facet deepCopy() {
        WaterlevelFacet copy = new WaterlevelFacet();
        copy.set(this);
        copy.type    = type;
        copy.hash    = hash;
        copy.stateId = stateId;
        return copy;
    }


    @Override
    public Object getData(Artifact artifact, CallContext context) {
        if (logger.isDebugEnabled()) {
            logger.debug("Get data for historical discharge curves at index: " +
                index + " / stateId: " + stateId);
        }

        FLYSArtifact flys = (FLYSArtifact) artifact;

        CalculationResult res = (CalculationResult)
            flys.compute(context, hash, stateId, type,  false);

        WQTimerange[] wqts = (WQTimerange[]) res.getData();

        return wqts[index];
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
